@@ -1,6 +1,7 @@
 /* structs.h
 
 Copyright (C) 1999-2003 Tom Gilbert.
+Copyright (C) 2010-2011 Daniel Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -33,5 +34,9 @@ typedef struct __feh_file_info feh_file_info;
 typedef struct __winwidget _winwidget;
 typedef _winwidget *winwidget;
 typedef struct __fehoptions fehoptions;
+typedef struct __fehkey fehkey;
+typedef struct __fehkb fehkb;
+typedef struct __fehbutton fehbutton;
+typedef struct __fehbb fehbb;
 
 #endif
